MethodChannelAesEncryptFile class

An implementation of AesEncryptFilePlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decryptBytes({required Uint8List cipherBytes, required String key, String? iv}) Future<Uint8List>
Decrypts cipherBytes (format: [16-byte IV][ciphertext]) and returns the original plaintext.
override
decryptFile({required String inputPath, required String outputPath, required String key, String? iv}) Future<bool>
Decrypts the file at inputPath and writes the result to outputPath.
override
encryptBytes({required Uint8List plainBytes, required String key, String? iv}) Future<Uint8List>
Encrypts plainBytes and returns [16-byte IV][ciphertext].
override
encryptFile({required String inputPath, required String outputPath, required String key, String? iv}) Future<bool>
Encrypts the file at inputPath and writes the result to outputPath.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited