storeVirtualFile static method
Stores bytes under path so they can be used as input to
encryptFile or decryptFile.
Implementation
static void storeVirtualFile(String path, Uint8List bytes) {
_virtualFileSystem[path] = bytes;
}
Stores bytes under path so they can be used as input to
encryptFile or decryptFile.
static void storeVirtualFile(String path, Uint8List bytes) {
_virtualFileSystem[path] = bytes;
}