- Inheritance
-
- Object
- PlatformInterface
- AesEncryptFilePlatform
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decryptBytes({required Uint8List cipherBytes, required String key, String? iv})
→ Future<Uint8List>
-
Decrypts
cipherBytes (format: [16-byte IV][ciphertext]) and returns
the original plaintext.
-
decryptFile({required String inputPath, required String outputPath, required String key, String? iv})
→ Future<bool>
-
Decrypts the file at
inputPath and writes the result to outputPath.
-
encryptBytes({required Uint8List plainBytes, required String key, String? iv})
→ Future<Uint8List>
-
Encrypts
plainBytes and returns [16-byte IV][ciphertext].
-
encryptFile({required String inputPath, required String outputPath, required String key, String? iv})
→ Future<bool>
-
Encrypts the file at
inputPath and writes the result to outputPath.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited